==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/services/ecr/PublicGalleryAuthorizationToken.java <==
package software.amazon.awscdk.services.ecr;

/**
 * (experimental) Authorization token to access the global public ECR Gallery via Docker CLI.
 * <p>
 * @see https://docs.aws.amazon.com/AmazonECR/latest/public/public-registries.html#public-registry-auth
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:26:16.778Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_ecr.PublicGalleryAuthorizationToken")
public class PublicGalleryAuthorizationToken extends software.amazon.jsii.JsiiObject {

    protected PublicGalleryAuthorizationToken(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PublicGalleryAuthorizationToken(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * (experimental) Grant access to retrieve an authorization token.
     * <p>
     * @param grantee This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static void grantRead(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.IGrantable grantee) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecr.PublicGalleryAuthorizationToken.class, "grantRead", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(grantee, "grantee is required") });
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/ecr/PublicGalleryAuthorizationToken.java <==
package software.amazon.awscdk.services.ecr;

/**
 * Authorization token to access the global public ECR Gallery via Docker CLI.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * User user = new User(this, "User");
 * PublicGalleryAuthorizationToken.grantRead(user);
 * </pre></blockquote>
 * <p>
 * @see https://docs.aws.amazon.com/AmazonECR/latest/public/public-registries.html#public-registry-auth
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:09.389Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_ecr.PublicGalleryAuthorizationToken")
public class PublicGalleryAuthorizationToken extends software.amazon.jsii.JsiiObject {

    protected PublicGalleryAuthorizationToken(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PublicGalleryAuthorizationToken(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * Grant access to retrieve an authorization token.
     * <p>
     * @param grantee This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static void grantRead(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.iam.IGrantable grantee) {
        software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecr.PublicGalleryAuthorizationToken.class, "grantRead", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(grantee, "grantee is required") });
    }
}
